%Original system of equation, modified by introduction of Hill-like 
%energy dependence

close all; clear; clc;

global k1 k2 k3 k4 k5 k6 Ka Kb Ke n Po deg_x1 deg_x2 deg_x6 alpha1 alpha2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Initial Concentration of Promoters
Po= 5;  

%Rate constants
k1 = 0.3;  % k1 = 0.3 for C1, take k1 = 0 for C2 
k2 = 100;  k3 = 100; 
k4 = 100;  k5 = 100;
k6 = 20*k1;

% half-saturation coefficient for "Energy" Hill-function
Ke = 20; 

% + co-operativity coeff - representation of degree of E-dependence
n=2; 

%Coefficients associated with gene transcription - ptet & gfp
alpha1 = 1;
alpha2 = 0.9;

%Degradation Terms in min-1
deg_x1 = 0;
deg_x2 = 0;
deg_x6 = 0.0005; % deg_GFP

% Initial Energy in System (initial conc. of nutrient medium)
Eo = 8; 

% Defining Time Span (in minutes)
tmax = 300;
tstep = 0.1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Vary parameters
ahl_0 = [0.1 1 5 10 50 100];

k1 = 0.3;     
LuxR_0 = 0;

C1_outputs = [];

for AHL_0 = ahl_0 % in nM
    
  %Sending all these parameters to ODE solver
  %[ ]s in nM -  from experiments expression at [AHL] = 10nM
  
  [t,x] = ode15s('ID_EnergyODE',[0:tstep:tmax],[LuxR_0; AHL_0; 0; Po; 0; 0; Eo]);
  
  Out = x(:,6); %x6 = GFP; x7 = E
  C1_outputs = [C1_outputs Out];
  
end

  
  %Plot effect on GFP expression = output
  %[FP] vs Time
  figure(1);
  plot(t, C1_outputs(:, 1), t, C1_outputs(:, 2), t, C1_outputs(:, 3), t, C1_outputs(:, 4), t, C1_outputs(:, 5), t, C1_outputs(:, 6));
  legend('0.1 a.u.', '1 a.u.', '5 a.u.', '10 a.u.', '50 a.u.', '100 a.u.');

   
  xlabel('time (min)');
% ylabel('[GFP] (a.u)');
  ylabel('[Energy] (a.u.)');
  title('Construct 1: [Energy] vs Time (varying [AHL]_0)');
  axis([0 tmax 0 12]);
 

