%Original system of equation, modified by introduction of Hill-like 
%energy dependence

close all; clear; clc;

global k1 k2 k3 k4 k5 k6 Ke n Po deg_x1 deg_x2 deg_x6 alpha1 alpha2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Initial Concentration of Promoters
Po= 5;  

%Rate constants
k1 = 0.3;   % k1 = 0.01 for C1, take k1 = 0 for C2 
k2 = 100;  k3 = 100; 
k4 = 100;  k5 = 100;
k6 = 20*k1;

% half-saturation coefficient for "Energy" Hill-function
Ke = 20; 

% + co-operativity coeff - representation of degree of E-dependence
n=2; 

%Coefficients associated with gene transcription - ptet & gfp
alpha1 = 1;
alpha2 = 0.9;

%Degradation Terms in min-1
deg_x1 = 0;
deg_x2 = 0;
deg_x6 = 0.0005; % deg_GFP

% Initial Energy in System (initial conc. of nutrient medium)
Eo = 8; 

% Defining Time Span (in minutes)
tmax = 300;
tstep = 0.1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Initial Conditions
LuxR_0 = 0;
AHL_0 =  50;

out1 = [];

deg= linspace(0, 0.05, 5); % deg_GFP array
degr = [];  
   
%Compute dynamical behaviour: GFP - 6; E - 7
for deg_x6 = deg
    
  degr = [degr deg_x6];

  [t,x] = ode15s('ID_EnergyODE',[0:tstep:tmax],[LuxR_0; AHL_0; 0; Po; 0; 0; Eo]);
 
  final = x(:, 6);
  out1 = [out1 final];
  
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Plots
figure(2);
plot(t, out1(:,1), t, out1(:,2), t, out1(:,3), t, out1(:,4), t, out1(:,5));
xlabel('time (min)','fontweight','b')
ylabel(['[GFP]'],'fontweight','b')
title('Construct 1 - varying delta_{GFP}','fontsize',14,'fontweight','b')
legend([' ' num2str(degr(1)) ' min^{-1}'], [' ' num2str(degr(2)) ' min^{-1}'],...
       [' ' num2str(degr(3)) ' min^{-1}'], [' ' num2str(degr(4)) ' min^{-1}'],...
       [' ' num2str(degr(5)) ' min^{-1}']);










  
